@@ -6,66 +6,68 @@
 #'Probability Density Functions (PDFs) (e.g. NAO index) obtained to combining 
 #'the Index PDFs for two Seasonal Forecast Systems (SFSs), the Best Index 
 #'estimation (see Sanchez-Garcia, E. et al (2019), 
-#'https://doi.org/10.5194/asr-16-165-2019 for more details about the 
+#'\doi{10.5194/asr-16-165-2019} for more details about the 
 #'methodology applied to estimate the Best Index).
 #'
 #'@references Regionally improved seasonal forecast of precipitation through 
 #'Best estimation of winter NAO, Sanchez-Garcia, E. et al.,
-#' Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
+#' Adv. Sci. Res., 16, 165174, 2019, \doi{10.5194/asr-16-165-2019}
 #'
 #'@param index_obs Index (e.g. NAO index) array from an observational database
-#' or reanalysis with at least a temporal dimension (by default 'time'), 
-#' which must be greater than 2.
+#'  or reanalysis with at least a temporal dimension (by default 'time'), 
+#'  which must be greater than 2.
 #'@param index_hind1 Index (e.g. NAO index) array from a SFS (named SFS1)
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be greater than 2. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and 'statistic' at the same time.
+#'  with at least two dimensions (time , member) or (time, statistic). 
+#'  The temporal dimension, by default 'time', must be greater than 2. 
+#'  The dimension 'member' must be greater than 1. The dimension 'statistic' 
+#'  must be equal to 2, for containing the two paramenters of a normal 
+#'  distribution (mean and sd) representing the ensemble of a SFS. It is not 
+#'  possible to have the dimension 'member' and 'statistic' 
+#'  at the same time.
 #'@param index_hind2 Index (e.g. NAO index) array from a SFS (named SFS2)
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be greater than 2. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
-#'@param index_fcst1 (optional, default = NULL) Index (e.g. NAO index) array from forescating of SFS1
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be equal to 1, the forecast year target. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
-#'@param index_fcst2 (optional, default = NULL) Index (e.g. NAO index) array from forescating of SFS2
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be equal to 1, the forecast year target. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
+#'  with at least two dimensions (time , member) or (time, statistic). 
+#'  The temporal dimension, by default 'time', must be greater than 2. 
+#'  The dimension 'member' must be greater than 1. 
+#'  The dimension 'statistic' must be equal to 2, for containing the two 
+#'  paramenters of a normal distribution (mean and sd) representing the ensemble 
+#'  of a SFS. It is not possible to have the dimension 'member' and  'statistic' 
+#'  together.
+#'@param index_fcst1 (optional, default = NULL) Index (e.g. NAO index) array 
+#'  from forescating of SFS1 with at least two dimensions (time , member) or 
+#'  (time, statistic). The temporal dimension, by default 'time', must be equal 
+#'  to 1, the forecast year target. The dimension 'member' must be greater than 
+#'  1. The dimension 'statistic' must be equal to 2, for containing the two 
+#'  paramenters of a normal distribution (mean and sd) representing the ensemble 
+#'  of a SFS. It is not possible to have the dimension 'member' and  'statistic' 
+#'  together.
+#'@param index_fcst2 (optional, default = NULL) Index (e.g. NAO index) array 
+#'  from forescating of SFS2 with at least two dimensions (time , member) or 
+#'  (time, statistic). The temporal dimension, by default 'time', must be equal 
+#'  to 1, the forecast year target. The dimension 'member' must be greater than 
+#'  1. The dimension 'statistic' must be equal to 2, for containing the two 
+#'  paramenters of a normal distribution (mean and sd) representing the ensemble 
+#'  of a SFS. It is not possible to have the dimension 'member' and  'statistic' 
+#'  together.
 #'@param method_BC A character vector of maximun length 2 indicating the bias 
-#'correction methodology to be applied on each SFS. If it is 'none' or any of 
-#'its elements is 'none', the bias correction won't be applied. 
-#'Available methods developped are "ME" (a bias correction scheme based on the
-#'mean error or bias between observation and predictions to correct the 
-#'predicted values), and "LMEV" (a bias correction scheme based on a linear 
-#'model using ensemble variance of index as predictor). (see Sanchez-Garcia, 
-#'E. et al (2019), https://doi.org/10.5194/asr-16-165-2019 for more details).
+#'  correction methodology to be applied on each SFS. If it is 'none' or any of 
+#'  its elements is 'none', the bias correction won't be applied. Available 
+#'  methods developped are "ME" (a bias correction scheme based on the mean 
+#'  error or bias between observation and predictions to correct the predicted 
+#'  values), and "LMEV" (a bias correction scheme based on a linear model using 
+#'  ensemble variance of index as predictor). (see Sanchez-Garcia, E. et al 
+#'  (2019), \doi{10.5194/asr-16-165-2019} for more details).
 #'@param time_dim_name A character string indicating the name of the temporal 
-#'dimension, by default 'time'.
+#'  dimension, by default 'time'.
 #'@param na.rm Logical (default = FALSE). Should missing values be removed? 
 #' 
-#' @return BEI_PDFBest() returns an array with the parameters that caracterize
-#' the PDFs, with at least a temporal dimension, by default 'time' and dimension 
-#' 'statistic' equal to 2.
-#' The firt statistic is the parameter 'mean' of the PDF for the best estimation
-#' combining the two SFSs PDFs.
-#' The second statistic is the parameter 'standard deviation' of the PDF for
-#' the best estimation combining the two SFSs PDFs.
-#' If index_fcst1 and/or index_fcst2 are null, returns the values for hindcast period. 
-#' Otherwise, it returns the values for a forecast year.
-#'@import multiApply
+#'@return BEI_PDFBest() returns an array with the parameters that caracterize
+#'the PDFs, with at least a temporal dimension, by default 'time' and dimension 
+#''statistic' equal to 2. The firt statistic is the parameter 'mean' of the PDF 
+#'for the best estimation combining the two SFSs PDFs. The second statistic is 
+#'the parameter 'standard deviation' of the PDF for the best estimation 
+#'combining the two SFSs PDFs. If index_fcst1 and/or index_fcst2 are null, 
+#'returns the values for hindcast period. Otherwise, it returns the values for a 
+#'forecast year.
 #' 
 #'@examples
 #' # Example 1 for the BEI_PDFBest function
@@ -81,10 +83,7 @@
 #' dim(index_fcst2) <- c(time = 1, member = 9, season = 2)
 #' method_BC <- 'ME'
 #' res <- BEI_PDFBest(index_obs, index_hind1, index_hind2, index_fcst1, 
-#' index_fcst2, method_BC) 
-#' dim(res)
-#' # time statistic    season
-#' #    1         2         2 
+#' index_fcst2, method_BC)  
 #' # Example 2 for the BEI_PDFBest function
 #' index_obs<- rnorm(10, sd = 3)
 #' dim(index_obs) <- c(time = 5, season = 2)
@@ -97,15 +96,14 @@
 #' index_fcst2 <- rnorm(18, mean = -0.5, sd = 4)
 #' dim(index_fcst2) <- c(time = 1, member = 9, season = 2)
 #' method_BC <- c('LMEV', 'ME')
-#' res <- BEI_PDFBest(index_obs, index_hind1, index_hind2, index_fcst1, index_fcst2, method_BC) 
-#' dim(res)
-#' # time statistic    season
-#' #    1         2         2 
+#' res <- BEI_PDFBest(index_obs, index_hind1, index_hind2, index_fcst1, 
+#'                    index_fcst2, method_BC) 
+#'@import multiApply
+#'@importFrom verification verify
 #'@export
-
-BEI_PDFBest <- function(index_obs, index_hind1, index_hind2, 
-                    index_fcst1 = NULL, index_fcst2 = NULL, method_BC = 'none',
-                    time_dim_name = 'time', na.rm = FALSE) {
+BEI_PDFBest <- function(index_obs, index_hind1, index_hind2, index_fcst1 = NULL, 
+                        index_fcst2 = NULL, method_BC = 'none',
+                        time_dim_name = 'time', na.rm = FALSE) {
                     
   if (!is.logical(na.rm)) {
     stop("Parameter 'na.rm' must be a logical value.")
@@ -122,7 +120,7 @@ BEI_PDFBest <- function(index_obs, index_hind1, index_hind2,
   if (!is.character(method_BC) || !is.vector(method_BC)){
     stop("Parameter 'method_BC' must be a character vector.")
   }
-  if (!(length(method_BC) == 1 || length(method_BC) == 2)){
+  if (!(length(method_BC) == 1 || length(method_BC) == 2)) {
     stop("Length of parameter 'method_BC' must be 1 or 2.")
   }
   if(!all(method_BC %in% c('ME', 'LMEV', 'none'))){
@@ -340,34 +338,28 @@ BEI_PDFBest <- function(index_obs, index_hind1, index_hind2,
 
 #' Atomic BEI_PDFBest
 #'@param pdf_1 Statistics array for the first SFS PDF with one dimension
-#' 'statistic' equal to 4.
-#' @param pdf_2 Statistics array for the second SFS PDF with one dimension
-#' 'statistic' equal to 4.
-#' @param bc_dataset1 Logical (default = TRUE).
-#' If TRUE the Index PDFs for the first SFS has been computed
-#' with bias corrected.
-#' @param bc_dataset2 Logical (default = TRUE).
-#' If TRUE the Index PDFs for the second SFS has been computed
-#' with bias corrected.
+#'  'statistic' equal to 4.
+#'@param pdf_2 Statistics array for the second SFS PDF with one dimension
+#'  'statistic' equal to 4.
+#'@param bc_dataset1 Logical (default = TRUE).
+#'  If TRUE the Index PDFs for the first SFS has been computed with bias 
+#'  corrected.
+#'@param bc_dataset2 Logical (default = TRUE). If TRUE the Index PDFs for the 
+#'  second SFS has been computed with bias corrected.
 #' 
-#' @return .BEI_PDFBest returns an array with dimensions (statistic = 2).
-#' The firt statistic is the parameter 'mean' of the PDF for the best estimation
-#' combining the two SFSs PDF.
-#' The second statistic is the parameter 'standard deviation' of the PDF for
-#' the best estimation combining the two SFSs PDF.
+#'@return .BEI_PDFBest returns an array with dimensions (statistic = 2).
+#'The firt statistic is the parameter 'mean' of the PDF for the best estimation
+#'combining the two SFSs PDF. The second statistic is the parameter 'standard 
+#'deviation' of the PDF for the best estimation combining the two SFSs PDF.
 #' 
-#' @examples
+#'@examples
 #' # Example for the Atomic BEI_PDFBest function
 #' pdf_1 <- c(1.1,0.6,1.6,0.9)
 #' dim(pdf_1) <-  c(statistic = 4)
 #' pdf_2 <- c(1,0.5,1.5,0.8)
 #' dim(pdf_2) <-  c(statistic = 4)
 #' res <- .BEI_PDFBest(pdf_1, pdf_2, bc_dataset1 = TRUE, bc_dataset2 = FALSE)
-#' str(res)
-#' dim(res)
-#' # statistic
-#' #    2
-#' @noRd
+#'@noRd
 .BEI_PDFBest <- function(pdf_1, pdf_2, bc_dataset1 = TRUE, bc_dataset2 = TRUE) {
   if(bc_dataset1){
     # apply bias correction to model 1
@@ -404,33 +396,34 @@ BEI_PDFBest <- function(index_obs, index_hind1, index_hind2,
 #' (e.g. NAO index) to improve the index estimate from SFSs for a hindcast period.
 #'
 #'@references Regionally improved seasonal forecast of precipitation through Best
-#' estimation of winter NAO, Sanchez-Garcia, E. et al.,
-#' Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
+#'estimation of winter NAO, Sanchez-Garcia, E. et al.,
+#'Adv. Sci. Res., 16, 165174, 2019, \doi{10.5194/asr-16-165-2019}
 #' 
 #'@param index_hind Index (e.g. NAO index) array from SFSs
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be greater than 2. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
+#'  with at least two dimensions (time , member) or (time, statistic). 
+#'  The temporal dimension, by default 'time', must be greater than 2. 
+#'  The dimension 'member' must be greater than 1. 
+#'  The dimension 'statistic' must be equal to 2, for containing the two 
+#'  paramenters of a normal distribution (mean and sd) representing the ensemble 
+#'  of a SFS. It is not possible to have the dimension 'member' and  'statistic' 
+#'  together.
 #'@param index_obs Index (e.g. NAO index) array from an observational database
-#' or reanalysis with at least a temporal dimension (by default 'time'), 
-#' which must be greater than 2.
+#'  or reanalysis with at least a temporal dimension (by default 'time'), 
+#'  which must be greater than 2.
 #'@param method A character string indicating which methodology is applied
-#' to compute the PDFs. One of "ME" (default) or "LMEV".
-#'@param time_dim_name A character string indicating the name of the temporal dimension, by default 'time'.
+#'  to compute the PDFs. One of "ME" (default) or "LMEV".
+#'@param time_dim_name A character string indicating the name of the temporal 
+#'  dimension, by default 'time'.
 #'@param na.rm Logical (default = FALSE). Should missing values be removed?
 #'
-#'@return an array with at least two dimensions (time, statistic = 4).
-#' The firt statistic is the parameter 'mean' of the PDF with not bias corrected
-#' The second statistic is the parameter 'standard deviation' of the PDF
-#' with not bias corrected
-#' The third statistic is the parameter 'mean' of the PDF with bias corrected
-#' The fourth statistic is the parameter 'standard deviation' of the PDF
-#' with bias corrected
-#' @import multiApply
-#' @examples
+#'@return An array with at least two dimensions (time, statistic = 4). The firt 
+#'statistic is the parameter 'mean' of the PDF with not bias corrected.
+#'The second statistic is the parameter 'standard deviation' of the PDF with not 
+#'bias corrected. The third statistic is the parameter 'mean' of the PDF with 
+#'bias corrected. The fourth statistic is the parameter 'standard deviation' of 
+#'the PDF with bias corrected.
+#'@import multiApply
+#'@examples
 #' # Example for the PDFIndexHind function
 #' # Example 1 
 #' index_obs <- 1 : (5 * 3 ) 
@@ -447,10 +440,9 @@ BEI_PDFBest <- function(index_obs, index_hind1, index_hind2,
 #' index_hind <- 1 : (5 * 2 * 3)
 #' dim(index_hind) <- c(time = 5, statistic = 2, season = 3)
 #' res <- PDFIndexHind(index_hind, index_obs)
-#' dim(res)
-#' # time statistic   season
-#' #    5         4        3
-#'@noRd
+#'@import multiApply
+#'@importFrom verification verify
+#'@export
 PDFIndexHind <- function(index_hind, index_obs, method ='ME', 
                          time_dim_name = 'time', na.rm = FALSE) {
   if (!is.character(time_dim_name)) {
@@ -529,42 +521,35 @@ PDFIndexHind <- function(index_hind, index_obs, method ='ME',
   return(PDFstatistics$output1)
 }
 
-
-
 #' Atomic PDFIndexHind
-#' @param index_hind Index (e.g. NAO index) array from a SFS with dimensions
-#' (time, member) or (time, statistic) for a hindcast period. 
-#' The temporal dimension, by default 'time', must be greater 
-#' than 2.
-#' @param index_obs Index (e.g. NAO index) array from an observational dataset
-#' or reanalysis with dimension (time). The temporal dimension, 
-#' by default 'time', must be greater than 2.
-#' @param method A character string indicating which methodology is applied
-#' to compute the PDF. One of "ME" (default) or "LMEV".
-#' @param time_dim_name A character string indicating the name of the temporal dimension, by default 'time'.
-#' @param na.rm Logical. Should missing values be removed?
-#' @return .PDFIndexHind returns an array with dimensions (time, statistic = 4).
-#' The firt statistic is the parameter 'mean' of the PDF with not bias corrected
-#' for the hindcast period.
-#' The second statistic is the parameter 'standard deviation' of the PDF
-#' with not bias corrected for the hindcast period.
-#' The third statistic is the parameter 'mean' of the PDF with bias corrected
-#' for the hindcast period.
-#' The fourth statistic is the parameter 'standard deviation' of the PDF
-#' with bias corrected for the hindcast period.
-#' @import multiApply
-#' @importFrom verification verify
-#' @examples
+#'@param index_hind Index (e.g. NAO index) array from a SFS with dimensions
+#'  (time, member) or (time, statistic) for a hindcast period. 
+#'  The temporal dimension, by default 'time', must be greater than 2.
+#'@param index_obs Index (e.g. NAO index) array from an observational dataset
+#'  or reanalysis with dimension (time). The temporal dimension, 
+#'  by default 'time', must be greater than 2.
+#'@param method A character string indicating which methodology is applied
+#'  to compute the PDF. One of "ME" (default) or "LMEV".
+#'@param time_dim_name A character string indicating the name of the temporal 
+#'  dimension, by default 'time'.
+#'@param na.rm Logical. Should missing values be removed?
+#'@return .PDFIndexHind returns an array with dimensions (time, statistic = 4).
+#'The firt statistic is the parameter 'mean' of the PDF with not bias corrected
+#'for the hindcast period. The second statistic is the parameter 'standard 
+#'deviation' of the PDF with not bias corrected for the hindcast period.
+#'The third statistic is the parameter 'mean' of the PDF with bias corrected 
+#'for the hindcast period. The fourth statistic is the parameter 'standard 
+#'deviation' of the PDF with bias corrected for the hindcast period.
+#'@examples
 #' # Example for the Atomic PDFIndexHind function
 #' index_obs <- 1 : 10
 #' dim(index_obs) <- c(time = length(index_obs))
 #' index_hind <- 1 : (10 * 3)
 #' dim(index_hind) <- c(time = 10, member = 3)
 #' res <- .PDFIndexHind(index_hind, index_obs)
-#' dim(res)
-#' # time statistic
-#' #  10         4
-#' @noRd
+#'@import multiApply
+#'@importFrom verification verify
+#'@noRd
 .PDFIndexHind <- function(index_hind, index_obs,  method = 'ME', 
                           time_dim_name = 'time', na.rm = FALSE) {
   dimnameshind <- names(dim(index_hind))
@@ -630,39 +615,40 @@ PDFIndexHind <- function(index_hind, index_obs, method ='ME',
 #' 
 #'@references Regionally improved seasonal forecast of precipitation through Best
 #' estimation of winter NAO, Sanchez-Garcia, E. et al.,
-#' Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
+#' Adv. Sci. Res., 16, 165174, 2019, \doi{10.5194/asr-16-165-2019}
 #' 
 #'@param index_hind Index (e.g. NAO index) array from SFSs
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be greater than 2. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
+#'  with at least two dimensions (time , member) or (time, statistic). 
+#'  The temporal dimension, by default 'time', must be greater than 2. 
+#'  The dimension 'member' must be greater than 1. 
+#'  The dimension 'statistic' must be equal to 2, for containing the two 
+#'  paramenters of a normal distribution (mean and sd) representing the ensemble 
+#'  of a SFS. It is not possible to have the dimension 'member' and  'statistic' 
+#'  together.
 #'@param index_obs Index (e.g. NAO index) array from an observational database
-#' or reanalysis with at least a temporal dimension (by default 'time'), 
-#' which must be greater than 2.
-#'@param index_fcst Index (e.g. NAO index) array from SFSs
-#' with at least two dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be equal to 1, the forecast year target. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
+#'  or reanalysis with at least a temporal dimension (by default 'time'), 
+#'  which must be greater than 2.
+#'@param index_fcst Index (e.g. NAO index) array from SFSs with at least two 
+#'  dimensions (time , member) or (time, statistic). The temporal dimension, by 
+#'  default 'time', must be equal to 1, the forecast year target. The dimension 
+#'  'member' must be greater than 1. The dimension 'statistic' must be equal to 
+#'  2, for containing the two paramenters of a normal distribution (mean and sd) 
+#'  representing the ensemble of a SFS. It is not possible to have the dimension 
+#'  'member' and  'statistic' together.
 #'@param method A character string indicating which methodology is applied
-#' to compute the PDFs. One of "ME" (default) or "LMEV".
-#'@param time_dim_name A character string indicating the name of the temporal dimension, by default 'time'.
+#'  to compute the PDFs. One of "ME" (default) or "LMEV".
+#'@param time_dim_name A character string indicating the name of the temporal 
+#'  dimension, by default 'time'.
 #'@param na.rm Logical (default = FALSE). Should missing values be removed?
 #'
-#'@return an array with at least two dimensions (time = 1, statistic = 4).
-#' The firt statistic is the parameter 'mean' of the PDF with not bias corrected
-#' The second statistic is the parameter 'standard deviation' of the PDF
-#' with not bias corrected
-#' The third statistic is the parameter 'mean' of the PDF with bias corrected
-#' The fourth statistic is the parameter 'standard deviation' of the PDF
-#' with bias corrected
-#' @import multiApply
-#' @examples
+#'@return An array with at least two dimensions (time = 1, statistic = 4).
+#'The firt statistic is the parameter 'mean' of the PDF with not bias corrected
+#'The second statistic is the parameter 'standard deviation' of the PDF with not 
+#'bias corrected. The third statistic is the parameter 'mean' of the PDF with 
+#'bias corrected. The fourth statistic is the parameter 'standard deviation' of 
+#'the PDF with bias corrected.
+#'@import multiApply
+#'@examples
 #' # Example for the PDFIndexFcst function
 #' index_fcst <- 1 : (8 * 4)
 #' dim(index_fcst) <- c(time = 1, member = 8, season = 4)
@@ -787,38 +773,35 @@ PDFIndexFcst <- function(index_hind, index_obs, index_fcst,
   return(PDFstatistics$output1)
 }
 
-#' Atomic PDFIndexFcst
-#' @param index_hind Index (e.g. NAO index) array from a SFS with dimensions
-#' (time, member) or (time, statistic) for a hindcast period. 
-#' The temporal dimension, by default 'time', must be greater 
-#' than 2.
-#' @param index_obs Index (e.g. NAO index) array from an observational dataset
-#' or reanalysis with dimension (time). The temporal dimension, 
-#' by default 'time', must be greater than 2.
-#' @param index_fcst Index (e.g. NAO index) array from SFSs
-#' with dimensions (time , member) or (time, statistic). 
-#' The temporal dimension, by default 'time', must be equal to 1, 
-#' the forecast year target. 
-#' The dimension 'member' must be greater than 1. 
-#' The dimension 'statistic' must be equal to 2, for containing the two paramenters of 
-#' a normal distribution (mean and sd) representing the ensemble of a SFS.
-#' It is not possible to have the dimension 'member' and  'statistic' together.
-#' @param method A character string indicating which methodology is applied
-#' to compute the PDF. One of "ME" (default) or "LMEV".
-#' @param time_dim_name A character string indicating the name of the temporal dimension, by default 'time'.
-#' @param na.rm Logical. Should missing values be removed?
-#' @return .PDFIndexFcst returns an array with dimensions (time = 1, statistic=4).
-#' The firt statistic is the parameter 'mean' of the PDF with not bias corrected
-#'  for the forecast year.
-#' The second statistic is the parameter 'standard deviation' of the PDF
-#' with not bias corrected for the forecast year.
-#' The third statistic is the parameter 'mean' of the PDF with bias corrected
-#' for the forecast year.
-#' The fourth statistic is the parameter 'standard deviation' of the PDF
-#' with bias corrected for the forecast year.
-#' @import multiApply
-#' @importFrom verification verify
-#' @examples
+#'Atomic PDFIndexFcst
+#'@param index_hind Index (e.g. NAO index) array from a SFS with dimensions
+#'  (time, member) or (time, statistic) for a hindcast period. The temporal 
+#'  dimension, by default 'time', must be greater than 2.
+#'@param index_obs Index (e.g. NAO index) array from an observational dataset
+#'  or reanalysis with dimension (time). The temporal dimension, by default 
+#'  'time', must be greater than 2.
+#'@param index_fcst Index (e.g. NAO index) array from SFSs with dimensions 
+#'  (time , member) or (time, statistic). The temporal dimension, by default 
+#'  'time', must be equal to 1, the forecast year target. The dimension 'member' 
+#'  must be greater than 1. The dimension 'statistic' must be equal to 2, for 
+#'  containing the two paramenters of a normal distribution (mean and sd) 
+#'  representing the ensemble of a SFS. It is not possible to have the dimension 
+#'  'member' and  'statistic' together.
+#'@param method A character string indicating which methodology is applied
+#'  to compute the PDF. One of "ME" (default) or "LMEV".
+#'@param time_dim_name A character string indicating the name of the temporal 
+#'  dimension, by default 'time'.
+#'@param na.rm Logical. Should missing values be removed?
+#'@return .PDFIndexFcst Returns an array with dimensions 
+#'(time = 1, statistic = 4). The firt statistic is the parameter 'mean' of the 
+#'PDF with not bias corrected for the forecast year. The second statistic is the 
+#'parameter 'standard deviation' of the PDF with not bias corrected for the 
+#'forecast year. The third statistic is the parameter 'mean' of the PDF with 
+#'bias corrected for the forecast year. The fourth statistic is the parameter 
+#''standard deviation' of the PDF with bias corrected for the forecast year.
+#'@import multiApply
+#'@importFrom verification verify
+#'@examples
 #' # Example 1 for the Atomic PDFIndexFcst function
 #' index_fcst <- 1 : (1 * 6)
 #' dim(index_fcst) <- c(time = 1, member = 6)
